@@ -170,7 +170,7 @@ static GESCommandLineOption options[] = {
       {
         "inpoint", "i", GST_TYPE_CLOCK_TIME, NULL,
         "Implies that the effect has 'internal content'"
-        "(see [ges_track_element_set_has_internal_source](ges_track_element_set_has_internal_source))",
+        " (see [ges_track_element_set_has_internal_source](ges_track_element_set_has_internal_source)).",
       },
       {
         "name", "n", 0, "child-name",
@@ -276,16 +276,16 @@ static GESCommandLineOption options[] = {
     .synopsis="<property name>",
     .description="Adds keyframes for the specified property in the form:\n\n",
     .examples="    ges-launch-1.0 +test-clip blue d=1.0 +keyframes posx 0=0 1.0=1280 t=direct-absolute +k posy 0=0 1.0=720 t=direct-absolute\n\n"
-              "This add a testclip that will disappear in the bottom right corner",
+              "This adds a testclip that will appear in the bottom right corner",
     .properties={
       {"property-name", 0, 0, NULL, NULL},
       {
         "binding-type", "t", 0, NULL,
-        "The type of binding to use, eg. 'direct-absolute', 'direct'"
+        "The type of binding to use, eg. 'direct-absolute', 'direct'."
       },
       {
         "interpolation-mode", "m", 0, NULL,
-        "The GstInterpolationMode to user."
+        "The GstInterpolationMode to use."
       },
       {
         "...", 0, 0, NULL,
@@ -301,12 +301,12 @@ static GESCommandLineOption options[] = {
     .synopsis="<property name> <value>",
     .description="Set a property on the last added element."
                  " Any child property that exists on the previously added element"
-                 " can be used as <property name>"
-                 "By default, set-<property-name> will lookup the property on the last added"
-                  "object.",
+                 " can be used as <property name>."
+                 " By default, set-<property-name> will lookup the property on the last added"
+                 " object.",
     .examples="    ges-launch-1.0 +clip /path/to/media set-alpha 0.3\n\n"
               "This will set the alpha property on \"media\" then play it back, assuming \"media\""
-              "contains a video stream.\n\n"
+              " contains a video stream.\n\n"
               "    ges-launch-1.0 +clip /path/to/media +effect \"agingtv\" set-dusts false\n\n"
               "This will set the \"dusts\" property of the agingtv to false and play the\n"
               "timeline back.",
@@ -467,6 +467,8 @@ _ges_command_line_formatter_add_clip (GESTimeline * timeline,
 {
   GESProject *proj;
   GESAsset *asset;
+  gboolean ret;
+
   if (!_cleanup_fields (options[CLIP].properties, structure, error))
     return FALSE;
 
@@ -478,9 +480,11 @@ _ges_command_line_formatter_add_clip (GESTimeline * timeline,
   proj = GES_PROJECT (ges_extractable_get_asset (GES_EXTRACTABLE (timeline)));
   asset = _ges_get_asset_from_timeline (timeline, GES_TYPE_URI_CLIP,
       gst_structure_get_string (structure, "asset-id"), NULL);
-  ges_project_add_asset (proj, asset);
 
-  return TRUE;
+  ret = ges_project_add_asset (proj, asset);
+  gst_object_unref (asset);
+
+  return ret;
 }
 
 static gboolean
@@ -782,7 +786,8 @@ _load (GESFormatter * self, GESTimeline * timeline, const gchar * string,
 
   gst_object_unref (parser);
 
-  ges_idle_add ((GSourceFunc) _set_project_loaded, g_object_ref (self), NULL);
+  ges_callback_add ((GSourceFunc) _set_project_loaded, g_object_ref (self),
+      NULL);
 
   return TRUE;
 
@@ -865,7 +870,8 @@ _serialize_control_binding (GESTrackElement * e, const gchar * prop,
 {
   GstInterpolationMode mode;
   GstControlSource *source = NULL;
-  GList *timed_values, *tmp;
+  GstTimedValue *timed_values;
+  gsize n_values;
   gboolean absolute = FALSE;
   GstControlBinding *binding = ges_track_element_get_control_binding (e, prop);
 
@@ -897,18 +903,18 @@ _serialize_control_binding (GESTrackElement * e, const gchar * prop,
             mode)->value_nick);
 
   timed_values =
-      gst_timed_value_control_source_get_all
-      (GST_TIMED_VALUE_CONTROL_SOURCE (source));
-  for (tmp = timed_values; tmp; tmp = tmp->next) {
+      gst_timed_value_control_source_list_control_points
+      (GST_TIMED_VALUE_CONTROL_SOURCE (source), &n_values);
+  for (gint i = 0; i < n_values; i++) {
     gchar strbuf[G_ASCII_DTOSTR_BUF_SIZE];
     GstTimedValue *value;
 
-    value = (GstTimedValue *) tmp->data;
+    value = &timed_values[i];
     g_string_append_printf (res, " %f=%s",
         (gdouble) value->timestamp / (gdouble) GST_SECOND,
         g_ascii_dtostr (strbuf, G_ASCII_DTOSTR_BUF_SIZE, value->value));
   }
-  g_list_free (timed_values);
+  g_free (timed_values);
 
 done:
   g_clear_object (&source);
@@ -1135,6 +1141,9 @@ ges_command_line_formatter_get_timeline_uri (GESTimeline * timeline)
 
         _sanitize_argument (ges_uri_clip_get_uri (GES_URI_CLIP (clip)), res);
         option = &options[CLIP];
+      } else if (GES_IS_TRANSITION_CLIP (clip)) {
+        g_string_append (res, " +transition");
+        option = &options[CLIP];
       } else {
         g_warning ("Unhandled clip type: %s", G_OBJECT_TYPE_NAME (clip));
         continue;
