@@ -444,8 +444,6 @@ G_GNUC_INTERNAL void _ges_container_set_height            (GESContainer * contai
  *                  GESClip                         *
  ****************************************************/
 G_GNUC_INTERNAL void              ges_clip_set_layer              (GESClip *clip, GESLayer  *layer);
-G_GNUC_INTERNAL gboolean          ges_clip_is_moving_from_layer   (GESClip *clip);
-G_GNUC_INTERNAL void              ges_clip_set_moving_from_layer  (GESClip *clip, gboolean is_moving);
 G_GNUC_INTERNAL GESTrackElement*  ges_clip_create_track_element   (GESClip *clip, GESTrackType type);
 G_GNUC_INTERNAL GList*            ges_clip_create_track_elements  (GESClip *clip, GESTrackType type);
 G_GNUC_INTERNAL gboolean          ges_clip_can_set_inpoint_of_child (GESClip * clip, GESTrackElement * child, GstClockTime inpoint, GError ** error);
@@ -547,8 +545,9 @@ ges_effect_from_description                   (const gchar *bin_desc,
  ****************************************************/
 typedef enum
 {
-  GES_CLIP_IS_MOVING = (1 << 0),
+  GES_CLIP_FREEZE_TRACK_ELEMENTS = (1 << 0),
   GES_TIMELINE_ELEMENT_SET_SIMPLE = (1 << 1),
+  GES_CLIP_IS_MOVING_BETWEEN_LAYERS = (1 << 2),
 } GESTimelineElementFlags;
 
 G_GNUC_INTERNAL GESTimelineElement * ges_timeline_element_peak_toplevel (GESTimelineElement * self);
