@@ -808,7 +808,7 @@ child_prop_changed_cb (GObject * child, GParamSpec * arg,
   data->arg = g_param_spec_ref (arg);
   data->self = gst_object_ref (self);
 
-  ges_idle_add ((GSourceFunc) emit_deep_notify_in_idle, data, NULL);
+  ges_callback_add ((GSourceFunc) emit_deep_notify_in_idle, data, NULL);
 }
 
 static gboolean
@@ -1932,15 +1932,18 @@ ges_timeline_element_set_child_property_full (GESTimelineElement * self,
     const gchar * property_name, const GValue * value, GError ** error)
 {
   GParamSpec *pspec;
-  GObject *child;
+  gboolean res;
 
   g_return_val_if_fail (GES_IS_TIMELINE_ELEMENT (self), FALSE);
   g_return_val_if_fail (!error || !*error, FALSE);
 
-  if (!ges_timeline_element_lookup_child (self, property_name, &child, &pspec))
+  if (!ges_timeline_element_lookup_child (self, property_name, NULL, &pspec))
     goto not_found;
 
-  return set_child_property_by_pspec (self, pspec, value, error);
+  res = set_child_property_by_pspec (self, pspec, value, error);
+
+  g_param_spec_unref (pspec);
+  return res;
 
 not_found:
   {
@@ -2100,6 +2103,7 @@ ges_timeline_element_set_child_property_valist (GESTimelineElement * self,
     if (!ges_timeline_element_lookup_child (self, name, NULL, &pspec))
       goto not_found;
 
+    memset (&value, 0, sizeof (value));
     G_VALUE_COLLECT_INIT (&value, pspec->value_type, var_args,
         G_VALUE_NOCOPY_CONTENTS, &error);
 
